@@ -24,7 +24,7 @@ class Query(object):
             "Accept": "application/json",
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "User-Agent": "Python API 1.81 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.82 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
@@ -40,9 +40,9 @@ class Query(object):
     def _raise_exception_from_response(self, response):
         try:
             message = json.loads(response.text).get("message")
-        except Exception as e:
-            raise Exception(response.text)
-        else:
+        except json.decoder.JSONDecodeError as e:
+            message = response.text
+        finally:
             raise Exception(message)
 
     def _requests(self, method, url, headers={}, data={}, json={}, params={}):
@@ -238,6 +238,14 @@ class Query(object):
         if not dataset_id:
             return {}
 
+        if start and limit:
+            self._start = start
+            self._limit = limit
+        if self._start < 1:
+            raise Exception('Start offset is less than 1')
+        if self._limit < 1:
+            raise Exception('Limit offset is less than 1')
+
         # 1. POST
         response = self._requests(
             method='post',
@@ -266,7 +274,11 @@ class Query(object):
                 headers=dict(
                     self._headers,
                     **{"Accept": "application/vnd.thinknum.table+json"}
-                )
+                ),
+                params={
+                    "start": self._start,
+                    "limit": self._limit
+                }
             )
             if response.status_code == self.OK:
                 is_created = True
@@ -281,13 +293,6 @@ class Query(object):
             raise Exception("Data still being fetched. Please retry it")
 
         # 3. GET
-        if start and limit:
-            self._start = start
-            self._limit = limit
-        if self._start < 1:
-            raise Exception('Start offset is less than 1')
-        if self._limit < 1:
-            raise Exception('Limit offset is less than 1')
         response = self._requests(
             method='get',
             url='{base_url}/datasets/{dataset_id}/query/{query_id}'.format(
